package com.sw.patroleditor.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.sw.patroleditor.component.rosBridge.RobotDataCallBack;
import com.sw.patroleditor.component.rosBridge.RobotDataModel;
import com.sw.patroleditor.domain.dto.AimDTO;
import com.sw.patroleditor.domain.dto.PointDTO;
import com.sw.patroleditor.domain.dto.TargetDTO;
import com.sw.patroleditor.domain.dto.ZoominDTO;
import com.sw.patroleditor.domain.vo.PointVO;
import com.sw.patroleditor.domain.vo.TargetVO;
import com.sw.patroleditor.mapper.AimMapper;
import com.sw.patroleditor.mapper.PointMapper;
import com.sw.patroleditor.mapper.TargetMapper;
import com.sw.patroleditor.mapper.ZoominMapper;
import com.sw.patroleditor.service.LocationService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.UUID;

/**
 * Created by shiwn on 2024/7/26 15:08
 */
@Service
public class LocationServiceImpl implements LocationService {
    @Resource
    private RobotDataCallBack robotDataCallBack;
    @Resource
    private PointMapper pointMapper;
    @Resource
    private TargetMapper targetMapper;
    @Resource
    private AimMapper aimMapper;
    @Resource
    private ZoominMapper zoominMapper;

    /**
     * @Description: 保存停靠点
     * @Date: 2024/7/26 15:09
     * @Author: shiwn
     */
    @Override
    public int savePoint(PointVO vo) {
        RobotDataModel robotDataModel = robotDataCallBack.getRobotDataModel();
        PointDTO dto = new PointDTO();
        dto.setUuid(UUID.randomUUID().toString().replaceAll("-", ""));
        dto.setType(vo.getType());
        dto.setNote(vo.getNote());
        dto.setAbsolutePosX(robotDataModel.getPosX());
        dto.setAbsolutePosY(robotDataModel.getPosY());
        return pointMapper.insert(dto);
    }

    /**
     * @Description: 保存巡检点
     * @Date: 2024/8/9 15:56
     * @Author: shiwn
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED, propagation = Propagation.REQUIRED, rollbackFor = Exception.class)
    public int saveTarget(TargetVO vo) {
        try {
            RobotDataModel robotDataModel = robotDataCallBack.getRobotDataModel();
            Long id = System.currentTimeMillis();
            //  巡检点数据TargetDTO
            TargetDTO targetDTO = new TargetDTO();
            targetDTO.setId(id);
            targetDTO.setPointId(vo.getPointId());
            targetDTO.setName(vo.getName());
            targetDTO.setInfo_0(vo.getInfo0());
            targetDTO.setInfo_1(vo.getInfo1());
            targetDTO.setInfo_2(vo.getInfo2());
            targetDTO.setInfo_3(vo.getInfo3());
            targetDTO.setInfo_4(vo.getInfo4());
            targetDTO.setInfo_9(vo.getInfo9());
            targetMapper.insert(targetDTO);

            //  巡检目标瞄准控制参数表AimDTO
            AimDTO aimDTO = new AimDTO();
            aimDTO.setId(id);
            aimDTO.setRoll(robotDataModel.getRoll());
            aimDTO.setPitch(robotDataModel.getPitch());
            aimDTO.setYaw(robotDataModel.getYaw());
            aimDTO.setHeight(robotDataModel.getPosZ());
            aimDTO.setFocus(robotDataModel.getFocalDistance());
            aimDTO.setRatio(robotDataModel.getRatio());
            aimDTO.setAperture(robotDataModel.getDiaphragm());
            aimDTO.setTopleftX(vo.getTopleftX());
            aimDTO.setTopleftY(vo.getTopleftY());
            aimDTO.setBotrightX(vo.getBotrightX());
            aimDTO.setBotrightY(vo.getBotrightY());
            aimMapper.insert(aimDTO);

            //  巡检目标抵近控制参数表ZoominDTO
            ZoominDTO zoominDTO = new ZoominDTO();
            zoominDTO.setId(id);
            zoominDTO.setRoll(robotDataModel.getRoll());
            zoominDTO.setPitch(robotDataModel.getPitch());
            zoominDTO.setYaw(robotDataModel.getYaw());
            zoominDTO.setFocus(robotDataModel.getFocalDistance());
            zoominDTO.setRatio(robotDataModel.getRatio());
            zoominDTO.setAperture(robotDataModel.getDiaphragm());
            zoominDTO.setTopleftX(vo.getTopleftX());
            zoominDTO.setTopleftY(vo.getTopleftY());
            zoominDTO.setBotrightX(vo.getBotrightX());
            zoominDTO.setBotrightY(vo.getBotrightY());
            zoominMapper.insert(zoominDTO);

            //  返回
            return 1;
        } catch (Exception e) {
            e.printStackTrace();
            return 0;
        }
    }

    /**
     * @Description: 删除停靠点
     * @Date: 2024/8/9 17:14
     * @Author: shiwn
     * @Param: pointId：
     * @Return:
     */
    @Override
    public int deletePoint(Integer pointId) {
        return pointMapper.deleteById(pointId);
    }

    /**
     * @Description: 删除巡检点
     * @Date: 2024/8/9 17:09
     * @Author: shiwn
     * @Param: targetId：
     * @Return:
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED, propagation = Propagation.REQUIRED, rollbackFor = Exception.class)
    public int deleteTarget(Long targetId) {
        try {
            targetMapper.deleteById(targetId);
            aimMapper.deleteById(targetId);
            zoominMapper.deleteById(targetId);
            return 1;
        } catch (Exception e) {
            e.getMessage();
            return 0;
        }
    }

    /**
     * @Description: 查询停靠点列表
     * @Date: 2024/8/19 17:31
     * @Author: shiwn
     * @Param: pageNum：
     * @Param: pageSize：
     * @Return:
     */
    @Override
    public PageInfo getPointList(Integer pageNum, Integer pageSize) {
        pageNum = pageNum == null ? 1 : pageNum;
        pageSize = pageSize == null ? 20 : pageSize;
        PageHelper.startPage(pageNum, pageSize);
        List<PointDTO> list = pointMapper.getList();
        PageInfo<PointDTO> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * @Description: 查询巡检点列表
     * @Date: 2024/8/19 17:37
     * @Author: shiwn
     * @Param: pageNum：
     * @Param: pageSize：
     * @Param: pointId：
     * @Return:
     */
    @Override
    public PageInfo getTargetList(Integer pageNum, Integer pageSize, Integer pointId) {
        pageNum = pageNum == null ? 1 : pageNum;
        pageSize = pageSize == null ? 20 : pageSize;
        PageHelper.startPage(pageNum, pageSize);
        List<TargetDTO> list = targetMapper.getList(pointId);
        PageInfo<TargetDTO> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }
}
